@@ -1196,7 +1196,8 @@ def init(ide, force, install):
 @click.option('--all', is_flag=True, help='Install all missing linters')
 @click.option('--yes', '-y', is_flag=True, help='Skip confirmation prompts')
 @click.option('--use-latest', is_flag=True, help='Install latest versions (bypass version pinning)')
-def install(tool, check, all, yes, use_latest):
+@click.option('--debug', is_flag=True, help='Show detailed debug output (especially for Windows Chocolatey installation)')
+def install(tool, check, all, yes, use_latest, debug):
     """
     Install security linters for your platform.
 
@@ -1258,7 +1259,7 @@ def install(tool, check, all, yes, use_latest):
             PackageManager.PACMAN: PacmanInstaller(),
             PackageManager.BREW: HomebrewInstaller(),
             PackageManager.WINGET: WingetInstaller(),
-            PackageManager.CHOCOLATEY: ChocolateyInstaller(),
+            PackageManager.CHOCOLATEY: ChocolateyInstaller(debug=debug),
         }
         installer = installer_map.get(pm)
 
@@ -1331,6 +1332,9 @@ def install(tool, check, all, yes, use_latest):
 
         console.print()
 
+        # Track if we just installed chocolatey in this session
+        chocolatey_just_installed = False
+
         # On Windows, check if chocolatey would be useful and offer to install it
         if platform_info.os_type.value == 'windows' and not ChocolateyInstaller.is_chocolatey_installed():
             # Check how many tools need chocolatey
@@ -1351,8 +1355,18 @@ def install(tool, check, all, yes, use_latest):
 
                 if install_choco:
                     console.print("[cyan]Installing Chocolatey...[/cyan]")
-                    if ChocolateyInstaller.install_chocolatey():
-                        console.print("[green]✅ Chocolatey installed successfully![/green]\n")
+                    if debug:
+                        console.print("[dim]Debug mode enabled - showing full output[/dim]")
+                    if ChocolateyInstaller.install_chocolatey(debug=debug):
+                        console.print("[green]✅ Chocolatey installed successfully![/green]")
+
+                        # Refresh PATH so chocolatey is available immediately
+                        from medusa.platform.installers.windows import refresh_windows_path
+                        refresh_windows_path()
+                        console.print("[dim]PATH refreshed - chocolatey is now available[/dim]\n")
+
+                        # Mark that we just installed it
+                        chocolatey_just_installed = True
                     else:
                         console.print("[red]❌ Failed to install Chocolatey (admin rights required)[/red]")
                         console.print("[dim]You can install manually: https://chocolatey.org/install[/dim]\n")
@@ -1380,8 +1394,9 @@ def install(tool, check, all, yes, use_latest):
             # On Windows, also check chocolatey as secondary package manager
             if platform_info.os_type.value == 'windows':
                 choco_package = ToolMapper.get_package_name(tool_name, 'choco')
-                if choco_package and ChocolateyInstaller.is_chocolatey_installed():
-                    choco_installer = ChocolateyInstaller()
+                # Use chocolatey if it's installed OR if we just installed it in this session
+                if choco_package and (chocolatey_just_installed or ChocolateyInstaller.is_chocolatey_installed()):
+                    choco_installer = ChocolateyInstaller(debug=debug)
 
             npm_package = ToolMapper.get_package_name(tool_name, 'npm')
             pip_package = ToolMapper.get_package_name(tool_name, 'pip')
