@@ -150,8 +150,9 @@ class WingetInstaller(BaseInstaller):
 class ChocolateyInstaller(BaseInstaller):
     """Windows package installer using Chocolatey"""
 
-    def __init__(self):
+    def __init__(self, debug: bool = False):
         super().__init__('choco')
+        self.debug = debug
 
     @staticmethod
     def is_chocolatey_installed() -> bool:
@@ -159,10 +160,14 @@ class ChocolateyInstaller(BaseInstaller):
         return shutil.which('choco') is not None
 
     @staticmethod
-    def install_chocolatey() -> bool:
+    def install_chocolatey(debug: bool = False) -> bool:
         """
         Install Chocolatey package manager
         Runs the official Chocolatey installation script
+        Note: Must be run from an admin PowerShell
+
+        Args:
+            debug: If True, shows all PowerShell output for debugging (default: False)
         """
         try:
             # Official Chocolatey install command
@@ -174,6 +179,7 @@ class ChocolateyInstaller(BaseInstaller):
                 "'https://community.chocolatey.org/install.ps1'))"
             )
 
+            # Run directly in current PowerShell (user must be admin already)
             cmd = [
                 'powershell',
                 '-NoProfile',
@@ -182,9 +188,64 @@ class ChocolateyInstaller(BaseInstaller):
                 install_script
             ]
 
-            result = subprocess.run(cmd, check=True, capture_output=True, text=True)
-            return result.returncode == 0
-        except subprocess.CalledProcessError:
+            if debug:
+                print(f"[DEBUG] Running command: {' '.join(cmd)}")
+                print("[DEBUG] This will download and run the Chocolatey install script...")
+                print("[DEBUG] PowerShell output below:")
+                print("-" * 60)
+
+            # Run and wait for completion
+            # In debug mode: show all output, don't capture it
+            # In normal mode: capture output to keep it clean
+            if debug:
+                result = subprocess.run(cmd, check=False, text=True, timeout=300)
+            else:
+                result = subprocess.run(cmd, check=False, capture_output=True, text=True, timeout=300)
+
+            if debug:
+                print("-" * 60)
+                print(f"[DEBUG] Command exit code: {result.returncode}")
+
+            # Verify chocolatey was actually installed by checking for the executable
+            # Wait a moment for installation to finalize
+            import time
+            if debug:
+                print("[DEBUG] Waiting 3 seconds for installation to finalize...")
+            time.sleep(3)
+
+            # Refresh PATH to pick up chocolatey
+            if debug:
+                print("[DEBUG] Refreshing Windows PATH from registry...")
+            refresh_windows_path()
+
+            # Check if choco is now accessible
+            if debug:
+                print("[DEBUG] Checking if 'choco' is in PATH...")
+            choco_exe = shutil.which('choco')
+            if debug:
+                print(f"[DEBUG] shutil.which('choco') returned: {choco_exe}")
+
+            if not choco_exe:
+                # Check default install location
+                default_path = r'C:\ProgramData\chocolatey\bin\choco.exe'
+                if debug:
+                    print(f"[DEBUG] Checking default location: {default_path}")
+                if os.path.exists(default_path):
+                    choco_exe = default_path
+                    if debug:
+                        print(f"[DEBUG] Found at default location!")
+                elif debug:
+                    print(f"[DEBUG] NOT found at default location")
+
+            if debug:
+                print(f"[DEBUG] Final result: chocolatey {'INSTALLED' if choco_exe else 'NOT INSTALLED'}")
+
+            return choco_exe is not None
+        except Exception as e:
+            if debug:
+                print(f"[DEBUG] Exception during installation: {type(e).__name__}: {e}")
+                import traceback
+                traceback.print_exc()
             return False
 
     def install(self, package: str, sudo: bool = False) -> bool:
@@ -199,7 +260,18 @@ class ChocolateyInstaller(BaseInstaller):
         cmd = ['choco', 'install', package_name, '-y']
 
         try:
-            result = self.run_command(cmd, check=True)
+            if self.debug:
+                print(f"[DEBUG] Running: {' '.join(cmd)}")
+                print("[DEBUG] Chocolatey output:")
+                print("-" * 60)
+                # Don't capture output in debug mode - let it show
+                result = subprocess.run(cmd, check=False, text=True)
+                print("-" * 60)
+                print(f"[DEBUG] Exit code: {result.returncode}")
+            else:
+                # Normal mode - capture output
+                result = self.run_command(cmd, check=True)
+
             success = result.returncode == 0
 
             # If install succeeded, refresh PATH
@@ -208,7 +280,11 @@ class ChocolateyInstaller(BaseInstaller):
                 refresh_windows_path()
 
             return success
-        except:
+        except Exception as e:
+            if self.debug:
+                print(f"[DEBUG] Exception during install: {type(e).__name__}: {e}")
+                import traceback
+                traceback.print_exc()
             return False
 
     def is_installed(self, package: str) -> bool:
